==> kdemultimedia-2.0.tar.bz2: kdemultimedia-2.0/mpeglib/lib/output/yuvDumper.cpp <==
/*
  writes yuv images on HD
  Copyright (C) 2000  Martin Vogt

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU Library General Public License as published by
  the Free Software Foundation.

  For more information look at the file COPYRIGHT in this package

 */


#include "yuvDumper.h"

YUVDumper::YUVDumper() {
  picCnt=1;
  method=_DUMP_YUV_AS_FRAME;
}

YUVDumper::~YUVDumper() {
}


int YUVDumper::openWindow(int w, int h,const char*) {
  
  FILE* formatFile=fopen("stream.yuv.format","w+");
  fprintf(formatFile,"Version 0.1\nw:%dh:%d\n",w,h);
  fclose(formatFile);



  if (method == _DUMP_YUV_AS_STREAM) {
    FILE* outFile=fopen("stream.yuv","w+");
    fclose(outFile);
  }
 return true;
}

void YUVDumper::closeWindow() {
}


void YUVDumper::flushWindow() {
}


int YUVDumper::getMethod() {
  return method;
}


void YUVDumper::setMethod(int method) {
  this->method=method;
}

void YUVDumper::unlockPictureArray(PictureArray* pictureArray) {
  YUVPicture* pic=pictureArray->getYUVPictureCallback();
  if (pic == NULL) {
    return;
  }

  FILE* outFile=NULL;

  if (method == _DUMP_YUV_AS_FRAME) {
    char dir[100];
    mode_t mode=S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH;
    
    snprintf(dir,100,"rec");
    if (mkdir(dir,mode) < 0) {
      perror("mkdir");
    }
    if (picCnt < 10) {
      snprintf(dir,100,"rec/0%d",picCnt);
    } else {
      snprintf(dir,100,"rec/%d",picCnt);
    }
    cout << "create:"<<dir<<endl;
    
    if (mkdir(dir,mode ) < 0) {
      perror("mkdir");
    }  
    
    picCnt++;
    
    char file[100];
    snprintf(file,100,"%s/image.yuv",dir);
    cout << "write:"<<file<<endl;
    outFile=fopen(file,"w+");
  }
  if (method == _DUMP_YUV_AS_STREAM) {
    outFile=fopen("stream.yuv","a+");
  }

  if (outFile == NULL) {
      perror("fopen");
      return;
  }

  int lumSize=pic->getLumLength();
  int colorSize=pic->getColorLength();
  fwrite(pic->getLuminancePtr(),1,lumSize,outFile);
  fwrite(pic->getCrPtr(),1,colorSize,outFile);
  fwrite(pic->getCbPtr(),1,colorSize,outFile);
  fclose(outFile);

}

==> kdemultimedia-3.5.10.tar.bz2: kdemultimedia-3.5.10/mpeglib/lib/output/yuvDumper.cpp <==
/*
  writes yuv images on HD
  Copyright (C) 2000  Martin Vogt

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU Library General Public License as published by
  the Free Software Foundation.

  For more information look at the file COPYRIGHT in this package

 */


#include "yuvDumper.h"

YUVDumper::YUVDumper() {
  picCnt=1;
  method=_DUMP_YUV_AS_STREAM;
}

YUVDumper::~YUVDumper() {
}


int YUVDumper::openWindow(int w, int h,const char*) {
  
  FILE* formatFile=fopen("stream.yuv.format","w+");
  fprintf(formatFile,"Version 0.1\nw:%dh:%d\n",w,h);
  fclose(formatFile);



  if (method == _DUMP_YUV_AS_STREAM) {
    FILE* outFile=fopen("stream.yuv","w+");
    fclose(outFile);
  }
 return true;
}

void YUVDumper::closeWindow() {
}


void YUVDumper::flushWindow() {
}


int YUVDumper::getMethod() {
  return method;
}


void YUVDumper::setMethod(int method) {
  this->method=method;
}

void YUVDumper::unlockPictureArray(PictureArray* pictureArray) {
  YUVPicture* pic=pictureArray->getYUVPictureCallback();
  if (pic == NULL) {
    return;
  }

  FILE* outFile=NULL;

  if (method == _DUMP_YUV_AS_STREAM) {
    outFile=fopen("stream.yuv","a+");
  }

  if (outFile == NULL) {
      perror("fopen");
      return;
  }

  int lumSize=pic->getLumLength();
  int colorSize=pic->getColorLength();
  fwrite(pic->getLuminancePtr(),1,lumSize,outFile);
  fwrite(pic->getCrPtr(),1,colorSize,outFile);
  fwrite(pic->getCbPtr(),1,colorSize,outFile);
  fclose(outFile);

}
